@@ -1,5 +1,7 @@
 from django.contrib import admin
 
+from loducode_utils.models import City, PaymentRecord
+
 
 class ReadOnlyAdmin(admin.ModelAdmin):
     readonly_fields = (
@@ -14,4 +16,12 @@ class ReadOnlyStackedInline(admin.StackedInline):
 class ReadOnlyTabularInline(admin.TabularInline):
     readonly_fields = (
         'created_at', 'modified_at', 'created_by', 'modified_by'
-    )
\ No newline at end of file
+    )
+
+class CityAdmin(ReadOnlyAdmin):
+    list_display = ("name","state")
+    list_display_links = ("name","state")
+    list_filter = ("state",)
+    search_fields = ("name",)
+
+admin.site.register(City, CityAdmin)
\ No newline at end of file
